package Lire::Config::Legacy;

use strict;

use vars qw($VERSION %map);

use Lire::Config;
use Lire::Config::Values;
use Lire::Config::Build qw/ac_info/;
use Symbol;

BEGIN {
    $VERSION = '$Revision: 1.16 $' =~ m!Revision: ([.\d]+)!;

    %map = (
        'LR_GZIP' => 'gzip_path',
        'LR_TAR' => 'tar_path',
        'LR_ZIP' => 'zip_path',
        'LR_SENDMAIL' => 'sendmail_path',
        'LR_PLOTICUS' => 'ploticus_path',
        'LR_GHOSTSCRIPT' => 'ghostscript_path',
        'LR_SKIP_ID_TEST' => 'lr_test_uid',
        'LR_KEEP' => 'lr_keep',
        'LR_ARCHIVE' => 'lr_archive',
        'LR_ARCHIVEDIR' => 'lr_archive_dir',
        'LR_DEBUG' => 'lr_debug',
        'LR_LOGGING' => 'lr_logging_method',
        'LR_FACILITY' => 'lr_logging_facility',
        'LR_LOGGERTAG' => 'lr_logging_tag',
        'LR_DEFAULT_OUTPUT_FORMAT' => 'lr_output_format',
        'LR_INCLUDEIMAGES' => 'lr_images',
        'LR_IMAGE_FORMAT' => 'lr_image_format',
        'LR_IMAGE_STYLE' => 'lr_image_style',
        'LR_IMAGE_RESOLUTION' => 'lr_image_resolution',
        'LR_SCALE_BYTES' => 'lr_scale_bytes',
        'LR_SCALE_SEC' => 'lr_scale_seconds',
        'LR_SCALE_NUMBER' => 'lr_scale_numbers',
        'LR_USERLEVEL' => 'lr_user_level',
        'LR_WEEK_NUMBERING' => 'lr_week_numbering',
        'LR_PDF_STYLE' => 'lr_pdf_style',
        'LR_DBK_XML_DTD' => 'lr_dbk_xml_dtd',
        'LR_DBK_HTML_XSL' => 'lr_dbk_html_xsl',
        'LR_DBK_HTML_ONEPAGE_XSL' => 'lr_dbk_html_onepage_xsl',
        'LR_DBK_XHTML_XSL' => 'lr_dbk_xhtml_xsl',
        'LR_DBK_XHTML_ONEPAGE_XSL' => 'lr_dbk_xhtml_onepage_xsl',
        'LR_DBK_FO_XSL' => 'lr_dbk_fo_xsl',
        'LR_XMLCATALOG' => 'xmlcatalog_path',
        'LR_XSLT_PROCESSOR' => 'lr_xslt_processor',
        'LR_XSLTPROC' => 'xsltproc_path',
        'LR_JADE' => 'jade_path',
        'LR_PDFJADETEX' => 'pdfjadetex_path',
        'LR_PDFXMLTEX' => 'pdfxmltex_path',
        'LR_DBK_PRINT_STYLESHEET' => 'lr_dbk_print_stylesheet',
        'LR_DBK_XML_DTD' => 'lr_dbk_xml_dtd',
        'LR_SPOOLDIR' => 'lr_spool_dir',
        'LR_SPOOLINTERVAL' => 'lr_spool_interval',
        'LR_EXPLANATIONFILE' => 'lr_mail_explanation',
        'LR_DISCLAIMERFILE' => 'lr_mail_disclaimer',
        'LR_SIGNATUREFILE' => 'lr_mail_signature',
    );
}

sub env2xml_file {
    my $old_sh_file = $_[0];

    my $converted = 0;
    my $xml_file = _compute_xml_filename( $old_sh_file );
    my $cfg_file
      = new Lire::Config::ConfigFile( 'spec' => Lire::Config->config_spec,
                                      'filename' => $xml_file, );
    my $cfg = $cfg_file->global( Lire::Config->config_spec->instance );
    while ( my ( $old_var, $new_var ) = each %map ) {
        if ( defined $ENV{$old_var} ) {
            $cfg->get( $new_var )->set( $ENV{$old_var} );
            $converted++;
        }
    }

    return ($converted, $cfg_file);
}

sub _compute_xml_filename {
    my $file = $_[0];

    my $pkg = ac_info( 'PACKAGE' );
    if ( index( $file, "/\.lire/etc" ) > 0 ) {
        $file =~ s,/\.lire/etc,/\.lire/config,;
    } else {
        $file =~ s,/$pkg/([^/]+)$,/$pkg/config/$1,;
    }

    return $file . ".xml";
}

1;

__END__

=pod

=head1 NAME

Lire::Config::Legacy - Convert environment variables to XML

=head1 DESCRIPTION

This module contains one function, env2xml_file, which takes the name
of an old sh-type configuration file as an argument and writes a corresponding
XML version of it using the configuration information from %ENV.

Because of this, it only works when started using a proper wrapper which loads
the shell config file and sets the environment variables.

=head1 VERSION

$Id: Legacy.pm,v 1.16 2003/10/29 06:19:18 wsourdeau Exp $

=head1 COPYRIGHT

Copyright (C) 2003 Stichting LogReport Foundation LogReport@LogReport.org

This file is part of Lire.

Lire is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program (see COPYING); if not, check with
http://www.gnu.org/copyleft/gpl.html or write to the Free Software
Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111, USA.

=head1 AUTHOR

Wessel Dankers <wsl@logreport.org>

=cut

